@@ -43,8 +43,6 @@ AAptInterface::AAptInterface(QObject* parent = 0) : QObject(parent)
 	iProcAptGetSimulate = new QProcess(this);
 	iProcAptGetInstall = new QProcess(this);
 	iProcAptGetClean = new QProcess(this);
-	iThreadDateFetch = new DateFetchThread(this);
-	//iThreadFileRead = new FileReadThread(this);
 
 	iProcAptGetUpdate->setProcessChannelMode(QProcess::MergedChannels);
 	iProcAptGetSimulate->setProcessChannelMode(QProcess::MergedChannels);
@@ -65,8 +63,6 @@ AAptInterface::AAptInterface(QObject* parent = 0) : QObject(parent)
 	connect(iProcAptGetClean,SIGNAL(error(QProcess::ProcessError)),this,SLOT(errorAptGetClean(QProcess::ProcessError)));
 	connect(iProcAptGetClean,SIGNAL(finished(int,QProcess::ExitStatus)),this,SLOT(finishedAptGetClean(int,QProcess::ExitStatus)));
 
-	connect(iThreadDateFetch,SIGNAL(finished()),this,SLOT(finishedThreadDateFetch()));
-
 	iProcessPackages.clear();
 	iProcessPackagesOrig.clear();
 	iProcessPackageVersions.clear();
@@ -148,7 +144,7 @@ void AAptInterface::runNext()
 			errorAptGetClean( QProcess::FailedToStart );
 	}
 	if( iMode == ModeFetchDates )
-		startThreadFetchDates();
+		startFetchDates();
 
 	if( iMode == ModeReadPackages )
 		startPkgListRead();
@@ -232,15 +228,37 @@ bool AAptInterface::cancel()
 bool AAptInterface::startAptGetUpdate()
 {
 	iCanCancel = true;
+	iProcAptGetUpdateOutput.clear();
 
 	if( !this->writeRepositories() )
 		return false;
 
 	if( iUiDimmer ) {
-		iUiDimmer->updateText("Updating catalogs");
+		iUiDimmer->setProgress(0);
+		iUiDimmer->updateText("Updating catalogs");		
 	}
 
 	iCatalogCounter = 0;
+	iCatalogsTotal = 0;
+	for( int i=0; i<iRepositories.count(); i++ ) {
+		if( iRepositories.at(i) && iRepositories.at(i)->enabled() ) {
+			iCatalogsTotal += 2;
+			QStringList comp = iRepositories.at(i)->components().split(' ');
+			iCatalogsTotal += comp.count();
+		}
+	}
+
+	bool useproxy = iSettings->qsettings()->value("use_proxies",false).toBool();
+	QString http_proxy = iSettings->qsettings()->value("http_proxy","").toString();
+	QString https_proxy = iSettings->qsettings()->value("https_proxy","").toString();
+	QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+	if( useproxy ) {
+		if( http_proxy != "" )
+			env.insert("http_proxy", http_proxy);
+		if( https_proxy != "" )
+			env.insert("https_proxy", https_proxy);
+	}
+	iProcAptGetUpdate->setProcessEnvironment(env);
 
 	QString runBinary = "/usr/bin/apt-get";
 	QStringList runParameters;
@@ -281,6 +299,8 @@ bool AAptInterface::startAptGetInstall()
 	if( iProcessPackages.count()==0 )
 		return false;
 
+	iProcAptGetInstallOutput.clear();
+
 	//qDebug() << "running apt-get install";
 
 	QString runBinary = "/usr/bin/apt-get";
@@ -310,6 +330,18 @@ bool AAptInterface::startAptGetInstall()
 	iAptGetCurrentDownloadFileName = "";
 	iProgressCheckTimer = 0;
 
+	bool useproxy = iSettings->qsettings()->value("use_proxies",false).toBool();
+	QString http_proxy = iSettings->qsettings()->value("http_proxy","").toString();
+	QString https_proxy = iSettings->qsettings()->value("https_proxy","").toString();
+	QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+	if( useproxy ) {
+		if( http_proxy != "" )
+			env.insert("http_proxy", http_proxy);
+		if( https_proxy != "" )
+			env.insert("https_proxy", https_proxy);
+	}
+	iProcAptGetUpdate->setProcessEnvironment(env);
+
 	logToFile( runBinary + " " + runParameters.join(" ") );
 	iProcAptGetInstall->start(runBinary,runParameters);
 
@@ -332,17 +364,6 @@ bool AAptInterface::startAptGetClean()
 	return true;
 }
 
-void AAptInterface::startThreadFetchDates()
-{
-	logToFile( QString("Start fetching package dates") );
-	iThreadDateFetch->start();
-
-	if( iUiDimmer ) {
-		iUiDimmer->updateText("Fetching package date information");
-	}
-
-}
-
 QString AAptInterface::setQProcessErrorMessage(QProcess::ProcessError error)
 {
 	if( iTerminated ) {
@@ -365,6 +386,9 @@ void AAptInterface::errorAptGetUpdate(QProcess::ProcessError error)
 {
 	QString msg = setQProcessErrorMessage(error);
 
+	if( iUiDimmer )
+		iUiDimmer->setProgress(-1);
+
 	communicateStatusToUi(false, "Error", msg);
 	cleanAfterError();
 	iNeedRepoRefresh = true;
@@ -444,7 +468,7 @@ QString AAptInterface::finishProcessCommonErrorMessages(QByteArray& output)
 
 void AAptInterface::finishedAptGetUpdate(int exitCode, QProcess::ExitStatus exitStatus)
 {
-	QByteArray output = iProcAptGetUpdate->readAllStandardOutput();
+	//QByteArray output = iProcAptGetUpdate->readAllStandardOutput();
 	//logToFile( "Output from last process:\n---\n"+output );
 
 	if( iErrorDone ) {
@@ -460,10 +484,14 @@ void AAptInterface::finishedAptGetUpdate(int exitCode, QProcess::ExitStatus exit
 	{
 		success = false;
 		title = "Error";
-		msg = finishProcessCommonErrorMessages(output);
+		msg = finishProcessCommonErrorMessages(iProcAptGetUpdateOutput);
 	}
 
-	if( output.contains("Could not resolve host") || output.contains("W: Failed to fetch") || output.contains("Temporary failure resolving") ) {
+	if( iUiDimmer )
+		iUiDimmer->setProgress(-1);
+
+	if( iProcAptGetUpdateOutput.contains("Could not resolve ") || iProcAptGetUpdateOutput.contains("W: Failed to fetch") ||
+		iProcAptGetUpdateOutput.contains("Temporary failure resolving") ) {
 		success = false;
 		title = "Error";
 		msg = "Failed to update some or all of the catalogs. Check your network connection and/or repository configuration";
@@ -549,7 +577,7 @@ void AAptInterface::finishedAptGetSimulate(int exitCode, QProcess::ExitStatus ex
 
 void AAptInterface::finishedAptGetInstall(int exitCode, QProcess::ExitStatus exitStatus)
 {
-	QByteArray output = iProcAptGetInstall->readAllStandardOutput();
+	//QByteArray output = iProcAptGetInstall->readAllStandardOutput();
 	//logToFile( "Output from last process:\n---\n"+output );
 
 	if( iErrorDone ) {
@@ -565,7 +593,7 @@ void AAptInterface::finishedAptGetInstall(int exitCode, QProcess::ExitStatus exi
 	{
 		success = false;
 		title = "Error";
-		msg = finishProcessCommonErrorMessages(output);
+		msg = finishProcessCommonErrorMessages(iProcAptGetInstallOutput);
 	}
 
 	if( iProgressCheckTimer ) {
@@ -588,7 +616,8 @@ void AAptInterface::finishedAptGetInstall(int exitCode, QProcess::ExitStatus exi
 void AAptInterface::finishedAptGetClean(int exitCode, QProcess::ExitStatus exitStatus)
 {
 	QByteArray output = iProcAptGetClean->readAllStandardOutput();
-	logToFile( "Output from last process:\n---\n"+output );
+	// this should produce no output
+	//logToFile( "Output from last process:\n---\n"+output );
 
 	if( iErrorDone ) {
 		iErrorDone = false;
@@ -612,18 +641,11 @@ void AAptInterface::finishedAptGetClean(int exitCode, QProcess::ExitStatus exitS
 }
 
 
-void AAptInterface::finishedThreadDateFetch()
-{
-	logToFile( QString("Finished fetching package dates") );
-
-	communicateStatusToUi(true, "Operation finished", "Package dates fetched");
-	runNext();
-}
-
 void AAptInterface::uiUpdaterAptGetUpdate()
 {
 	QByteArray data = iProcAptGetUpdate->read( iProcAptGetUpdate->bytesAvailable() );
 	logToFile( data, false );
+	iProcAptGetUpdateOutput.append(data);
 
 	if( !iUiDimmer )
 		return;
@@ -635,13 +657,16 @@ void AAptInterface::uiUpdaterAptGetUpdate()
 		if( lines.at(i).startsWith("Get:") || lines.at(i).startsWith("Hit ") )
 			iCatalogCounter++;
 	}
-	iUiDimmer->updateText( QString("Updating catalogs (%1)").arg(iCatalogCounter) );
+	//iUiDimmer->updateText( QString("Updating catalogs (%1)").arg(iCatalogCounter) );
+	//qDebug() << iCatalogCounter << iCatalogsTotal;
+	iUiDimmer->setProgress( iCatalogCounter*100/iCatalogsTotal );
 }
 
 void AAptInterface::uiUpdaterAptGetInstall()
 {
 	QByteArray data = iProcAptGetInstall->read( iProcAptGetInstall->bytesAvailable() );
 	logToFile( data, false );
+	iProcAptGetInstallOutput.append(data);
 
 	if( !iUiDimmer )
 		return;
@@ -942,7 +967,8 @@ void AAptInterface::startPkgListRead()
 	//qDebug() << "reading package list files";
 
 	if( iUiDimmer ) {
-		iUiDimmer->updateText("Reading package lists");
+		iUiDimmer->updateText("Reading package lists<br>");
+		iUiDimmer->setProgress(0);
 	}
 
 // clear packages lists
@@ -969,6 +995,18 @@ void AAptInterface::startPkgListRead()
 	QDir dir("/var/lib/apt/lists/");
 	QFileInfoList files = dir.entryInfoList();
 
+	quint64 totaldatasize = 0;
+	quint64 currentreaddata = 0;
+	quint64 lastupdatedata = 0;
+	quint64 updateinterval = 1000000;
+	for( int i=0; i<files.count(); i++ )
+	{
+		if( files.at(i).fileName().endsWith("_Packages"))
+			totaldatasize += files.at(i).size();
+	}
+	QFileInfo dbinfo("/var/lib/dpkg/status");
+	totaldatasize += dbinfo.size();
+
 	for( int i=0; i<files.count(); i++ )
 	{
 		Repository* currentRepo = 0;
@@ -995,7 +1033,12 @@ void AAptInterface::startPkgListRead()
 			}
 
 			while (!db.atEnd() && !iTerminated) {
-				Package* newpkg = ReadNextPackage(db);
+				Package* newpkg = ReadNextPackage(db, currentreaddata);
+				//qDebug() << "read" << currentreaddata << "of" << totaldatasize;
+				if( iUiDimmer && currentreaddata >= lastupdatedata+updateinterval ) {
+					iUiDimmer->setProgress( currentreaddata*100/totaldatasize );
+					lastupdatedata = currentreaddata;
+				}
 				QApplication::processEvents();
 				pkgcount_apt++;
 				if( newpkg )
@@ -1010,6 +1053,7 @@ void AAptInterface::startPkgListRead()
 						{
 							iPackagesAvailable.remove(exists->name());
 							delete exists;
+							exists=0;
 							iPackagesAvailable.insert(newpkg->name(), newpkg);
 						} else {
 							if( newpkg->version() == exists->version() )
@@ -1024,6 +1068,8 @@ void AAptInterface::startPkgListRead()
 		}
 	}
 	if( iTerminated ) {
+		if( iUiDimmer )
+			iUiDimmer->setProgress(-1);
 		communicateStatusToUi(false, "Operation cancelled", "The operation was cancelled by user");
 		cleanAfterError();
 		return;
@@ -1044,7 +1090,11 @@ void AAptInterface::startPkgListRead()
 	}
 
 	while (!db.atEnd() && !iTerminated) {
-		Package* newpkg = ReadNextPackage(db);
+		Package* newpkg = ReadNextPackage(db, currentreaddata);
+		if( iUiDimmer && currentreaddata >= lastupdatedata+updateinterval ) {
+			iUiDimmer->setProgress( currentreaddata*100/totaldatasize );
+			lastupdatedata = currentreaddata;
+		}
 		QApplication::processEvents();
 		pkgcount_dpkg++;
 		if( newpkg ) {
@@ -1065,6 +1115,11 @@ void AAptInterface::startPkgListRead()
 	*/
 
 	logToFile( QString("Finished reading package lists") );
+	if( iUiDimmer ) {
+		iUiDimmer->updateText("Reading package lists<br><font size=\"-1\">Creating package view</font>");
+		QApplication::processEvents();
+		iUiDimmer->setProgress(-1);
+	}
 
 	if( iTerminated ) {
 		communicateStatusToUi(false, "Operation cancelled", "The operation was cancelled by user");
@@ -1077,7 +1132,7 @@ void AAptInterface::startPkgListRead()
 	runNext();
 }
 
-Package* AAptInterface::ReadNextPackage(QFile& f)
+Package* AAptInterface::ReadNextPackage(QFile& f, quint64& currentreaddata)
 {
 	iMultiLine=MultiLineNone;
 
@@ -1086,6 +1141,7 @@ Package* AAptInterface::ReadNextPackage(QFile& f)
 	bool pkgready = false;
 	while( !pkgready && !f.atEnd() ) {
 		QByteArray line = f.readLine();
+		currentreaddata += line.size();
 		if( processPackageDataLine(pkg,line) ) {
 			pkgready = true;
 		}
@@ -1184,44 +1240,71 @@ bool AAptInterface::processPackageDataLine(Package*& pkg, QByteArray& line)
 }
 
 
-
-
-DateFetchThread::DateFetchThread(QObject* parent) : QThread(parent)
+void AAptInterface::startFetchDates()
 {
-}
+	logToFile( QString("Start fetching package dates") );
 
-void DateFetchThread::run()
-{
-	//qDebug() << "thread fetchdates running";
+	//if( iUiDimmer ) {
+	//	iUiDimmer->updateText("Fetching package date information");
+	//}
 
-	/*QHashIterator<QString, Package*> i( *iAptIf->packages() );
+	QNetworkAccessManager* nam = new QNetworkAccessManager();
+
+	//connect(nam,SIGNAL(finished(QNetworkReply*)),this,SLOT(dateFetchNetworkReply(QNetworkReply*)));
+
+	QHashIterator<QString, Package*> i( iPackagesAvailable );
+	QString fn,fnf,datecmp;
+	int count=0;
 	while (i.hasNext())
 	{
 		i.next();
-	*/
+		count++;
+		iUiDimmer->updateText("Fetching package date information<br>" + QString("%1/%2").arg(count).arg(iPackagesAvailable.count()));
+		if( i.value()->repositories().at(0) && i.value()->fileNameFull()!="" ) {
+			int x = i.value()->fileNameFull().lastIndexOf('/');
+			fnf = i.value()->fileName();
+			if( x!=-1) {
+				fn = i.value()->fileNameFull().left(x);
+			} else {
+				fn = i.value()->fileNameFull();
+			}
 
-	/*
-	QNetworkAccessManager* nam = new QNetworkAccessManager();
+			datecmp = "<a href=\"" + fnf + "\">" + fnf + "</a>";
 
-	QUrl url("http://repository.maemo.org/extras-devel/pool/fremantle/free/f/fapman/fapman_0.3.2-1_armel.deb");
-	QNetworkRequest nw(url);
+			QNetworkRequest nwr(QUrl(i.value()->repositories().at(0)->url() + i.value()->repositories().at(0)->dir()
+									 + fn + '/'));
 
-	connect(nam,SIGNAL(finished(QNetworkReply*)),this,SLOT(networkReply(QNetworkReply*)));
+			//qDebug() << nwr.url();
+			//qDebug() << datecmp;
 
-	qDebug() << QDateTime::currentDateTime();
-	nam->get(nw);
+			QNetworkReply* reply = nam->get(nwr);
 
-	exec();
-	*/
-}
-
-void DateFetchThread::networkReply(QNetworkReply* )
-{
-	/*
-	qDebug() << QDateTime::currentDateTime();
-	QByteArray b;
-	qDebug() << reply->rawHeader(b);
-
-	quit();
-	*/
+			while(reply->isRunning()) {
+				QApplication::processEvents();
+				usleep(10000);
+			}
+
+			QByteArray data = reply->readAll();
+			delete reply;
+			//qDebug() << data;
+
+			int p = data.indexOf(datecmp);
+			//qDebug() << p;
+			QString k = "";
+			if( p!=-1 ) {
+				int z = data.indexOf('<', p+datecmp.length()+1);
+				if( z != -1 ) {
+					k = data.mid(p+datecmp.length()+1, z-(p+datecmp.length()+1) );
+				}
+			}
+			qDebug() << i.value()->name() << k.trimmed();
+		}
+	}
+
+	delete nam;
+
+	logToFile( QString("Finished fetching package dates") );
+
+	communicateStatusToUi(true, "Operation finished", "Package dates fetched");
+	runNext();
 }
