@@ -33,6 +33,9 @@ public:
 	void dim(QString title, QString message);
 	void undim();
 	bool busy() { return iBusy; }
+	void updateText(QString message);
+	void setProgress(int p_);
+	int progress() { return iProgress; }
 
 private:
 	int iAlpha;
@@ -41,11 +44,14 @@ private:
 	QLabel* iLabel;
 	bool iBusy;
 	QTimer* iTimer;
+	QString iTitle;
 
 	int iAnim;
 	int iAnimDir;
 	int iAnimY;
 
+	int iProgress;
+
 public slots:
 	void orientationChanged();
 
