@@ -22,9 +22,8 @@
 
 #include <QtCore>
 #include <QMainWindow>
-#include "aptinterface.h"
+#include "aaptinterface.h"
 
-class AptInterface;
 class PackageView;
 class Uninstall;
 class Dialog;
@@ -42,13 +41,12 @@ class MainWindow : public QMainWindow
     Q_OBJECT
 
 public:
-	enum operation { OpNone, OpInstall, OpUninstall, OpUpgrade, OpClean };
+	enum nextOperation { OpNone, OpPromptSimulated, OpOpenPkgView };
 
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
-	void operationFinished(AptInterface::aptMode lastMode_, bool success_, QString msg_);
-	void busyDialog(bool visible_, QString title="", QString text="");
-	void setOperation(operation op_) { iOperation=op_; }
+	void operationQueueFinished(QList<AAptInterface::interfaceMode> lastModes, bool success, QString title, QStringList msgs);
+	void busyDialog(bool show_, QString title="", QString text="");
 	void closeEvent(QCloseEvent *event);
 	void GdkEventIconThemeReload();
 
@@ -60,15 +58,16 @@ protected:
 
 private:
     Ui::MainWindow *ui;
-	AptInterface* iAptInterface;
+	AAptInterface* iAptInterface;
 	PackageView* iWinPackageView;
 	RepoView* iWinRepoView;
 	Dialog* iDlgBusy;
 	Settings* iSettings;
-	operation iOperation;
+	//operation iOperation;
 	dimmer* iDimmer;
 	bool iReposAutoUpdating;
 	bool iUpgradeAutoUpdate;
+	nextOperation iNextOperation;
 
 private slots:
 	void on_actionOptions_triggered();
