@@ -45,24 +45,6 @@ PackageSelector::PackageSelector(Package* pkg, QWidget *parent) :
 
 	longtext += "Category: " + pkg->section() + "<br>";
 
-	if( !pkg->isInstalled() )
-	{
-		longtext += "Repositories: ";
-		if( pkg->repositories().count()>0 ) {
-			for(int i=0; i<pkg->repositories().count(); i++ ) {
-				if( pkg->repositories().at(i) )
-					longtext += pkg->repositories().at(i)->name();
-				else
-					longtext += "unknown";
-				if( i<pkg->repositories().count()-1 )
-					longtext += ", ";
-			}
-			longtext += "<br>";
-		} else {
-			longtext += "unknown<br>";
-		}
-	}
-
 	if( pkg->isInstalled() ) {
 		longtext += "Package is installed, version <b>" + pkg->version() + "</b>";
 		if( pkg->installedSize() > 0 )
@@ -73,7 +55,7 @@ PackageSelector::PackageSelector(Package* pkg, QWidget *parent) :
 	longtext += "<br>";
 
 	if( pkg->isInstalled() ) {
-		longtext += "Installation time: ";
+		longtext += "Installation date: ";
 		if( pkg->date().isValid() )
 			longtext += pkg->date().toString("yyyy-MM-dd hh:mm");
 		else
@@ -94,6 +76,40 @@ PackageSelector::PackageSelector(Package* pkg, QWidget *parent) :
 		longtext += "<br>";
 	}
 
+	if( !pkg->isInstalled() ) {
+		longtext += "Available package date: ";
+		if( pkg->date().isValid() )
+			longtext += pkg->date().toString("yyyy-MM-dd hh:mm");
+		else
+			longtext += "Unknown";
+		longtext += "<br>";
+	} else if( pkg->isUpgradeable() ) {
+		longtext += "Available package date: ";
+		if( pkg->availablePackage() && pkg->availablePackage()->date().isValid() )
+			longtext += pkg->availablePackage()->date().toString("yyyy-MM-dd hh:mm");
+		else
+			longtext += "Unknown";
+		longtext += "<br>";
+	}
+
+	if( !pkg->isInstalled() )
+	{
+		longtext += "Repositories: ";
+		if( pkg->repositories().count()>0 ) {
+			for(int i=0; i<pkg->repositories().count(); i++ ) {
+				if( pkg->repositories().at(i) )
+					longtext += pkg->repositories().at(i)->name();
+				else
+					longtext += "unknown";
+				if( i<pkg->repositories().count()-1 )
+					longtext += ", ";
+			}
+			longtext += "<br>";
+		} else {
+			longtext += "unknown<br>";
+		}
+	}
+
 	if( pkg->isUpgradeable() )
 	{
 		longtext += "Repositories: ";
