@@ -28,6 +28,7 @@
 #include "help.h"
 #include "aaptinterface.h"
 #include "logview.h"
+#include "sortselector.h"
 
 PackageListWidgetItem::PackageListWidgetItem(Package* p_, QString name_) : QListWidgetItem(name_)
 {
@@ -136,7 +137,7 @@ void ListItemDelegate::loadIcons()
 
 QSize ListItemDelegate::sizeHint(const QStyleOptionViewItem&, const QModelIndex&) const
 {
-	return QSize(400, 60);
+	return QSize(400, 58);
 }
 
 
@@ -210,6 +211,8 @@ PackageView::PackageView(QWidget *parent) : QMainWindow(parent), ui(new Ui::Pack
 
 	iKeyFilter = new KeyEventGrabber(this);
 	ui->listWidget->installEventFilter(iKeyFilter);
+
+
 }
 
 PackageView::~PackageView()
@@ -254,8 +257,14 @@ QString PackageView::generateSortString(Package* pkg)
 	// default sort order is alphabetical by name
 	QString sortstr = pkg->displayName();
 
-	if( iSortOrder==SortDateDesc )
-		sortstr = pkg->date().toString("yyyy-MM-dd hh:mm");
+	if( iSortOrder==SortDateDesc ) {
+		if( pkg->date().isValid() )
+			sortstr = pkg->date().toString("yyyy-MM-dd hh:mm");
+		else {
+			sortstr = "";
+			iPackagesEmptySort++;
+		}
+	}
 	if( iSortOrder==SortSizeDesc ) {
 		if( pkg->isInstalled() )
 			sortstr = QString("%1").arg(pkg->installedSize()*1024, 12 );
@@ -272,6 +281,7 @@ void PackageView::openWin()
 {
 	ui->listWidget->clear();
 	ui->listWidget->setSortingEnabled(true);
+	iPackagesEmptySort = 0;
 
 	if( iSortOrder==SortDateDesc || iSortOrder==SortSizeDesc )
 		ui->listWidget->sortItems(Qt::DescendingOrder);
@@ -347,6 +357,12 @@ void PackageView::openWin()
 		iListCoverLabel->setText("No packages");
 		iListCoverLabel->show();
 	}
+
+	if( ui->listWidget->count()>0 && iPackagesEmptySort == ui->listWidget->count() ) {
+		ConfirmDialog d(false, this);
+		d.setText("Warning", "No packages have the required information for sorting by this criterion. Leaving list unsorted.");
+		d.exec();
+	}
 }
 
 void PackageView::enableMenu()
@@ -533,9 +549,11 @@ void PackageView::updateLabel()
 	if( iAptInterface->numSelectedPackages()==0 ) {
 		ui->btn_Commit->setEnabled(false);
 		ui->actionClear_selections->setVisible(false);
+		ui->actionSave_selections->setVisible(false);
 	} else {
 		ui->btn_Commit->setEnabled(true);
 		ui->actionClear_selections->setVisible(true);
+		ui->actionSave_selections->setVisible(true);
 	}
 }
 
@@ -593,6 +611,7 @@ void PackageView::resetWindow()
 {
 	iSelectedCatFilter = iDefaultCatFilter;
 	ui->btn_StatusFilter->setEnabled(true);
+	iSortOrder = SortAlpha;
 
 	clearSelections();
 	//if( iMainWindow )
@@ -716,21 +735,49 @@ void PackageView::on_actionUpgrade_all_triggered()
 	updateLabel();
 }
 
-void PackageView::on_btn_Sort_clicked()
-{
-	if( iSortOrder==SortAlpha )
-		iSortOrder = SortDateDesc;
-	else if( iSortOrder==SortDateDesc )
-		iSortOrder = SortSizeDesc;
-	else if( iSortOrder==SortSizeDesc )
-		iSortOrder = SortAlpha;
-
-	openWin();
-}
-
 void PackageView::on_actionView_log_triggered()
 {
 	QByteArray log = iAptInterface->readLogFile();
 	LogView l(log, this);
 	l.exec();
 }
+
+void PackageView::on_btn_Sort_clicked()
+{
+	SortSelector s(iSortOrder, this);
+	if( s.exec() ) {
+		iSortOrder = s.selectedOperation();
+		openWin();
+	}
+}
+
+void PackageView::on_actionLoad_selections_triggered()
+{
+
+}
+
+void PackageView::on_actionSave_selections_triggered()
+{
+	QHashIterator<QString, Package*> i( *iAptInterface->packagesAvailable() );
+	while (i.hasNext())
+	{
+		i.next();
+
+		if( i.value()->markedOperation() == Package::PkgOpInstallUpgrade )
+			qDebug() << i.value()->name() << i.value()->version() << "install";
+		if( i.value()->markedOperation() == Package::PkgOpRemove )
+			qDebug() << "Warning: package is marked for removal in the wrong list";
+
+	}
+
+	QHashIterator<QString, Package*> r( *iAptInterface->packagesInstalled() );
+	while (r.hasNext())
+	{
+		r.next();
+
+		if( r.value()->markedOperation() == Package::PkgOpInstallUpgrade )
+			qDebug() << i.value()->name() << i.value()->version() << "upgrade";
+		if( r.value()->markedOperation() == Package::PkgOpRemove )
+			qDebug() << i.value()->name() << i.value()->version() << "remove";
+	}
+}
