@@ -76,9 +76,10 @@ class PackageView : public QMainWindow
 {
     Q_OBJECT
 
+public:
+
 	enum sortOrder { SortAlpha, SortSizeDesc, SortDateDesc };
 
-public:
     explicit PackageView(QWidget *parent = 0);
     ~PackageView();
 	void openWin();
@@ -151,11 +152,15 @@ private:
 	QString iPrevSearchText;
 	KeyEventGrabber* iKeyFilter;
 
+	int iPackagesEmptySort;
+
 private slots:
+	void on_actionSave_selections_triggered();
+	void on_actionLoad_selections_triggered();
+	void on_btn_Sort_clicked();
 	void on_actionView_log_triggered();
- void on_btn_Sort_clicked();
- void on_actionUpgrade_all_triggered();
- void on_lineEdit_textEdited(QString );
+	void on_actionUpgrade_all_triggered();
+	void on_lineEdit_textEdited(QString );
 	void on_btn_searchClose_clicked();
 	void on_actionHelp_triggered();
 	void on_btn_StatusFilter_clicked();
